fuel-tasks-validator
====================

Project resources
-----------------


Project status, bugs, and blueprints are tracked on Launchpad:
https://launchpad.net/fuel

Development documentation is hosted here:
http://docs.mirantis.com/fuel-dev

User guide can be found here:
http://docs.mirantis.com

Any additional information can be found on the Fuel's project wiki:
https://wiki.openstack.org/wiki/Fuel

Anyone wishing to contribute to fuel-tasks-validator should follow the general
OpenStack process. A good reference for it can be found here:

* https://wiki.openstack.org/wiki/How_To_Contribute
* http://docs.openstack.org/infra/manual/developers.html
